\name{LakeAcidity}
\alias{LakeAcidity}
\title{Water Acidity in Lakes}
\description{
    Data extracted from the Eastern Lake Survey of 1984 conducted by the
    United States Environmental Protection Agency, concerning 112 lakes
    in the Blue Ridge.
}
\usage{data(LakeAcidity)}
\format{
    A list containing 112 observations on the following variables.
    \tabular{ll}{
	\code{ph} \tab Surface ph.\cr
	\code{cal} \tab Calcium concentration.\cr
	\code{lat} \tab Latitude.\cr
	\code{lon} \tab Longitude.\cr
	\code{geog} \tab Geographic location, derived from \code{lat}
	and \code{lon}
    }
}
\details{
    \code{geog} was generated from \code{lat} and \code{lon} using the
    code given in the Example section.
}
\source{
    Douglas, A. and Delampady, M. (1990), \emph{Eastern Lake Survey --
	Phase I: Documentation for the Data Base and the Derived Data
	sets.} Tech Report 160 (SIMS), Dept. Statistics, University of
        British Columbia.
}
\references{
    Gu, C. and Wahba, G. (1993), Semiparametric analysis of variance
    with tensor product thin plate splines.  \emph{Journal of the Royal
	Statistical Society Ser. B}, \bold{55}, 353--368.
}
\examples{
## Converting latitude and longitude to x-y coordinates
\dontrun{convert <- function(lat, lon) {
    lat <- lat/180*pi
    lon <- lon/180*pi
    m.lat <- (max(lat)+min(lat))/2
    m.lon <- (max(lon)+min(lon))/2
    x <- cos(m.lat)*sin(m.lon-lon)
    y <- sin(lat-m.lat)
    cbind(x,y)
}
data(LakeAcidity)
convert(LakeAcidity$lat,LakeAcidity$lon)
## Clean up
rm(LakeAcidity,convert)}
}
\keyword{datasets}

\eof
\name{aids}
\alias{aids}
\title{AIDS Incubation}
\description{
    A data set collected by Centers for Disease Control and Prevention
    concerning AIDS patients who were infected with the HIV virus
    through blood transfusion.
}
\usage{data(aids)}
\format{
    A data frame containing 295 observations on the following variables.
    \tabular{ll}{
	\code{incu} \tab Time from HIV infection to AIDS diagnosis.\cr
	\code{infe} \tab Time from HIV infection to end of data
	collection (July 1986).\cr
	\code{age} \tab Age at time of blood transfusion.
    }
}
\source{
    Wang, M.-C. (1989), A semiparametric model for randomly truncated
    data.  \emph{Journal of the American Statistical Association},
    \bold{84}, 742--748. 
}
\keyword{datasets}

\eof
\name{bacteriuria}
\alias{bacteriuria}
\title{Treatment of Bacteriuria}
\description{
    Bacteriuria patients were randomly assigned to two treatment
    groups.  Weekly binary indicator of bacteriuria was recorded for
    every patient over 4 to 16 weeks.  A total of 72 patients were
    represented in the data, with 36 each in the two treatment groups.
}
\usage{data(bacteriuria)}
\format{
    A data frame containing 820 observations on the following variables.
    \tabular{ll}{
	\code{id} \tab Identification of patients, a factor.\cr
	\code{trt} \tab Treatments 1 or 2, a factor.\cr
	\code{time} \tab Weeks after randomization.\cr
	\code{infect} \tab Binary indicator of bacteriuria (bacteria in
	urine).
    }
}
\source{
    Joe, H. (1997), \emph{Multivariate Models and Dependence Concepts}.
    London: Chapman and Hall.
}
\references{
    Gu and Ma (2003b), \emph{Generalized Nonparametric Mixed-Effect
    Models: Computation and Smoothing Parameter Selection}.  Available
    at \url{http://stat.purdue.edu/~chong/manu.html}.
}
\keyword{datasets}

\eof
\name{buffalo}
\alias{buffalo}
\title{Buffalo Annual Snowfall}
\description{
    Annual snowfall accumulations in Buffalo, NY from 1910 to 1973.
}
\usage{data(buffalo)}
\format{
    A vector of 64 numerical values.
}
\source{
    Scott, D. W. (1985), Average shifted histograms: Effective
    nonparametric density estimators in several dimensions.  \emph{The
    Annals of Statistics}, \bold{13}, 1024--1040.
}
\keyword{datasets}

\eof
\name{cdssden}
\alias{cdssden}
\alias{cpssden}
\alias{cqssden}
\title{Evaluating Conditional PDF, CDF, and Quantiles of Smoothing Spline Density Estimates}
\description{
    Evaluate conditional pdf, cdf, and quantiles for smoothing spline
    density estimates.
}
\usage{
cdssden(object, x, cond, int)
cpssden(object, q, cond, int)
cqssden(object, p, cond, int)
}
\arguments{
    \item{object}{Object of class \code{"ssden"}.}
    \item{x}{Data frame or vector of points on which conditional density
        is to be evaluated.}
    \item{cond}{One row data frame of conditioning variables.}
    \item{int}{Normalizing constant.}
    \item{q}{Vector of points on which conditional cdf is to be
        evaluated.}
    \item{p}{Vector of probabilities for which conditional quantiles are
        to be calculated.}
}
\value{
    \code{cdssden} returns a list object with the following components.
    \item{pdf}{Vector of conditional pdf.}
    \item{int}{Normalizing constant.}
      
    \code{cpssden} and \code{cpssden} return a vector of conditional cdf
    or quantiles.
}
\details{
    The argument \code{x} in \code{cdssden} is of the same form as the
    argument \code{newdata} in \code{\link{predict.lm}}, but can take a
    vector for 1-D conditional densities.

    \code{cpssden} and \code{cqssden} naturally only work for 1-D
    conditional densities.
}
\note{
    \code{cpssden} and \code{cqssden} can be very slow.
}
\seealso{
    \code{\link{ssden}} and \code{\link{dssden}}.
}
\keyword{models}
\keyword{distribution}
\keyword{smooth}

\eof
\name{drkpk}
\alias{sspdsty}
\alias{mspdsty}
\alias{msphzd}
\title{Numerical Engine for ssden and sshzd}
\description{
    Calculate penalized likelihood density estimates and hazard
    estimates via the Newton iteration and evaluate the cross-validation
    score, as implemented in the RATFOR routine \code{dnewton.r} and
    \code{hzdnewton.r}, and minimize the cross-validation score using
    \code{\link{nlm}} and \code{\link{nlm0}}.
}
\usage{
sspdsty(s,r,q,cnt,qd.s,qd.r,qd.wt,prec,maxiter,alpha)
mspdsty(s,r,q,cnt,qd.s,qd.r,qd.wt,prec,maxiter,alpha)

msphzd(s,r,q,Nobs,cnt,qd.s,qd.r,qd.wt,prec,maxiter,alpha)
}
\details{
    \code{sspdsty} is used by \code{\link{ssden}} to compute
    cross-validated density estimate with a single smoothing
    parameter. \code{mspdsty} is used by \code{\link{ssden}} to compute
    cross-validated density estimate with multiple smoothing
    parameters.

    \code{msphzd} is used by \code{\link{sshzd}} to compute
    cross-validated hazard estimate with single or multiple smoothing
    parameters.
}
\arguments{
    \item{s}{Unpenalized terms evaluated at data points.}
    \item{r}{Basis of penalized terms evaluated at data points.}
    \item{q}{Penalty matrix.}
    \item{Nobs}{Total number of lifetime observations.}
    \item{cnt}{Bin-counts for histogram data.}
    \item{qd.s}{Unpenalized terms evaluated at quadrature nodes.}
    \item{qd.r}{Basis of penalized terms evaluated at quadrature nodes.}
    \item{qd.wt}{Quadrature weights.}
    \item{prec}{Precision requirement for internal iterations.}
    \item{maxiter}{Maximum number of iterations allowed for
        internal iterations.}
    \item{alpha}{Parameter defining cross-validation score for smoothing
        parameter selection.}
}
\references{
    Gu, C. and Wang, J. (2002), \emph{Penalized Likelihood Density
    Estimation: Direct Cross-Validation and Scalable Approximation}.
    Available at \url{stat.purdue.edu/~chong/manu.html}.

    Gu, C. (2002), \emph{Smoothing Spline ANOVA Models}.  New York:
    Springer-Verlag.
}
\keyword{smooth}

\eof
\name{dssden}
\alias{dssden}
\alias{pssden}
\alias{qssden}
\title{Evaluating PDF, CDF, and Quantiles of Smoothing Spline Density Estimates}
\description{
    Evaluate pdf, cdf, and quantiles for smoothing spline density
    estimates.
}
\usage{
dssden(object, x)
pssden(object, q)
qssden(object, p)
}
\arguments{
    \item{object}{Object of class \code{"ssden"}.}
    \item{x}{Data frame or vector of points on which density is to be
        evaluated.}
    \item{q}{Vector of points on which cdf is to be evaluated.}
    \item{p}{Vector of probabilities for which quantiles are to be
        calculated.}
}
\value{
    A vector of pdf, cdf, or quantiles.
}
\details{
    The argument \code{x} in \code{dssden} is of the same form as the
    argument \code{newdata} in \code{\link{predict.lm}}, but can take a
    vector for 1-D densities.

    \code{pssden} and \code{qssden} naturally only work for 1-D
    densities.
}
\seealso{
    \code{\link{ssden}} and \code{\link{cdssden}}.
}
\keyword{models}
\keyword{distribution}
\keyword{smooth}

\eof
\name{family}
\alias{mkdata.binomial}
\alias{dev.resid.binomial}
\alias{dev.null.binomial}
\alias{cv.binomial}
\alias{y0.binomial}
\alias{proj0.binomial}
\alias{kl.binomial}
\alias{cfit.binomial}
\alias{mkdata.poisson}
\alias{dev.resid.poisson}
\alias{dev.null.poisson}
\alias{cv.poisson}
\alias{y0.poisson}
\alias{proj0.poisson}
\alias{kl.poisson}
\alias{cfit.poisson}
\alias{y0.Gamma}
\alias{mkdata.Gamma}
\alias{dev.resid.Gamma}
\alias{dev.null.Gamma}
\alias{cv.Gamma}
\alias{y0.Gamma}
\alias{proj0.Gamma}
\alias{kl.Gamma}
\alias{cfit.Gamma}
\alias{mkdata.inverse.gaussian}
\alias{dev.resid.inverse.gaussian}
\alias{dev.null.inverse.gaussian}
\alias{mkdata.nbinomial}
\alias{dev.resid.nbinomial}
\alias{dev.null.nbinomial}
\alias{cv.nbinomial}
\alias{y0.nbinomial}
\alias{proj0.nbinomial}
\alias{kl.nbinomial}
\alias{cfit.nbinomial}
\alias{mkdata.weibull}
\alias{dev.resid.weibull}
\alias{dev.null.weibull}
\alias{cv.weibull}
\alias{y0.weibull}
\alias{proj0.weibull}
\alias{kl.weibull}
\alias{cfit.weibull}
\alias{mkdata.lognorm}
\alias{dev.resid.lognorm}
\alias{dev0.resid.lognorm}
\alias{dev.null.lognorm}
\alias{cv.lognorm}
\alias{y0.lognorm}
\alias{proj0.lognorm}
\alias{kl.lognorm}
\alias{cfit.lognorm}
\alias{mkdata.loglogis}
\alias{dev.resid.loglogis}
\alias{dev0.resid.loglogis}
\alias{dev.null.loglogis}
\alias{cv.loglogis}
\alias{y0.loglogis}
\alias{proj0.loglogis}
\alias{kl.loglogis}
\alias{cfit.loglogis}
\title{Utility Functions for Error Families}
\description{
    Utility functions for fitting Smoothing Spline ANOVA models with
    non-Gaussian responses.
}
\usage{
mkdata.binomial(y, eta, wt, offset)
dev.resid.binomial(y, eta, wt)
dev.null.binomial(y, wt, offset)
cv.binomial(y, eta, wt, hat, alpha)
y0.binomial(y, eta0, wt)
proj0.binomial(y0, eta, offset)
kl.binomial(eta0, eta1, wt)
cfit.binomial(y, wt, offset)

mkdata.poisson(y, eta, wt, offset)
dev.resid.poisson(y, eta, wt)
dev.null.poisson(y, wt, offset)
cv.poisson(y, eta, wt, hat, alpha, sr, q)
y0.poisson(eta0)
proj0.poisson(y0, eta, wt, offset)
kl.poisson(eta0, eta1, wt)
cfit.poisson(y, wt, offset)

mkdata.Gamma(y, eta, wt, offset)
dev.resid.Gamma(y, eta, wt)
dev.null.Gamma(y, wt, offset)
cv.Gamma(y, eta, wt, hat, rss, alpha)
y0.Gamma(eta0)
proj0.Gamma(y0, eta, wt, offset)
kl.Gamma(eta0, eta1, wt)
cfit.Gamma(y, wt, offset)

mkdata.inverse.gaussian(y, eta, wt, offset)
dev.resid.inverse.gaussian(y, eta, wt)
dev.null.inverse.gaussian(y, wt, offset)

mkdata.nbinomial(y, eta, wt, offset, nu)
dev.resid.nbinomial(y, eta, wt)
dev.null.nbinomial(y, wt, offset)
cv.nbinomial(y, eta, wt, hat, alpha)
y0.nbinomial(y,eta0,nu)
proj0.nbinomial(y0, eta, wt, offset)
kl.nbinomial(eta0, eta1, wt, nu)
cfit.nbinomial(y, wt, offset, nu)

mkdata.weibull(y, eta, wt, offset, nu)
dev.resid.weibull(y, eta, wt, nu)
dev.null.weibull(y, wt, offset, nu)
cv.weibull(y, eta, wt, hat, nu, alpha)
y0.weibull(y, eta0, nu)
proj0.weibull(y0, eta, wt, offset, nu)
kl.weibull(eta0, eta1, wt, nu, int)
cfit.weibull(y, wt, offset, nu)

mkdata.lognorm(y, eta, wt, offset, nu)
dev.resid.lognorm(y, eta, wt, nu)
dev0.resid.lognorm(y, eta, wt, nu)
dev.null.lognorm(y, wt, offset, nu)
cv.lognorm(y, eta, wt, hat, nu, alpha)
y0.lognorm(y, eta0, nu)
proj0.lognorm(y0, eta, wt, offset, nu)
kl.lognorm(eta0, eta1, wt, nu, y0)
cfit.lognorm(y, wt, offset, nu)

mkdata.loglogis(y, eta, wt, offset, nu)
dev.resid.loglogis(y, eta, wt, nu)
dev0.resid.loglogis(y, eta, wt, nu)
dev.null.loglogis(y, wt, offset, nu)
cv.loglogis(y, eta, wt, hat, nu, alpha)
y0.loglogis(y, eta0, nu)
proj0.loglogis(y0, eta, wt, offset, nu)
kl.loglogis(eta0, eta1, wt, nu, y0)
cfit.loglogis(y, wt, offset, nu)
}
\arguments{
    \item{y}{Model response.}
    \item{eta}{Fitted values on link scale.}
    \item{wt}{Model weights.}
    \item{offset}{Model offset.}
    \item{nu}{Size for nbinomial.  Inverse scale for log life time.}
}
\details{
    These are not to be called by the user.

    \code{mkdata.x} create the pseudo data to be used in iterated
    penalized least squares fitting.  \code{dev.resid.x} calculate the
    deviance residuals.  \code{dev.null.x} calculate the deviance of the
    constant null model.
}
\seealso{
    \code{\link{gssanova}}.
}
\keyword{internal}

\eof
\name{fitted.ssanova}
\alias{fitted.ssanova}
\alias{residuals.ssanova}
\alias{fitted.gssanova}
\alias{residuals.gssanova}
\title{Fitted Values and Residuals from Smoothing Spline ANOVA Fits}
\description{
    Methods for extracting fitted values and residuals from smoothing
    spline ANOVA fits.
}
\usage{
fitted.ssanova(object, ...)
residuals.ssanova(object, ...)

fitted.gssanova(object, ...)
residuals.gssanova(object, type="working", ...)
}
\arguments{
    \item{object}{Object of class \code{"ssanova"} or \code{"gssanova"}.}
    \item{type}{Type of residuals desired, with two alternatives
      \code{"working"} (default) or \code{"deviance"}.}
    \item{...}{Ignored.}
}
\details{
    The fitted values for \code{"gssanova"} objects are on the link
    scale, the same scale the \code{"working"} residuals are on.
}
\keyword{models}
\keyword{regression}
\keyword{smooth}

\eof
\name{gastric}
\alias{gastric}
\title{Gastric Cancer Data}
\description{
    Survival of gastric cancer patients under chemotherapy and
    chemotherapy-radiotherapy combination.
}
\usage{data(gastric)}
\format{
    A data frame containing 90 observations on the following variables.
    \tabular{ll}{
	\code{futime} \tab Follow-up time, in days.\cr
	\code{status} \tab Censoring status.\cr
	\code{trt} \tab Factor indicating the treatments: 1 --
	chemothrapy, 2 -- combination.
    }
}
\source{
  Moreau, T., O'Quigley, J., and Mesbah, M. (1985), A global
  goodness-of-fit statistic for the proportional hazards model.
  \emph{Applied Statistics}, \bold{34}, 212-218.
}
\keyword{datasets}

\eof
\name{gauss.quad}
\alias{gauss.quad}
\title{Generating Gauss-Legendre Quadrature}
\description{
    Generate Gauss-Legendre quadratures using the FORTRAN routine
    \code{gaussq.f} found at NETLIB.
}
\usage{
gauss.quad(size,interval)
}
\arguments{
    \item{size}{Size of quadrature.}
    \item{interval}{Interval to be covered.}
}
\value{
    \code{gauss.quad} returns a list object with the following components.
    \item{pt}{Quadrature nodes.}
    \item{wt}{Quadrature weights.}
}
\keyword{math}

\eof
\name{gssanova}
\alias{gssanova}
\title{Fitting Smoothing Spline ANOVA Models with Non Gaussian Responses}
\description{
    Fit smoothing spline ANOVA models to responses from selected
    exponential families with cubic spline, linear spline, or thin-plate
    spline marginals for numerical variables.  Factors are also
    accepted.  The symbolic model specification via \code{formula}
    follows the same rules as in \code{\link{lm}} and \code{\link{glm}}.
}
\usage{
gssanova(formula, family, type="cubic", data=list(), weights, subset,
        offset, na.action=na.omit, partial=NULL, method=NULL,
        varht=1, nu=NULL, prec=1e-7, maxiter=30, ext=.05, order=2)
}
\arguments{
    \item{formula}{Symbolic description of the model to be fit.}
    \item{family}{Description of the error distribution.  Supported
	are exponential families \code{"binomial"}, \code{"poisson"},
	\code{"Gamma"}, \code{"inverse.gaussian"}, and
	\code{"nbinomial"}.  Also supported are accelerated life model
	families \code{"weibull"}, \code{"lognorm"}, and
	\code{"loglogis"}.}
    \item{type}{Type of numerical marginals to be used.  Supported
	are \code{type="cubic"} for cubic spline marginals,
	\code{type="linear"} for linear spline marginals, and
	\code{type="tp"} for thin-plate spline marginals.}
    \item{data}{Optional data frame containing the variables in the
	model.}
    \item{weights}{Optional vector of weights to be used in the
	fitting process.}
    \item{subset}{Optional vector specifying a subset of observations
	to be used in the fitting process.}
    \item{offset}{Optional offset term with known parameter 1.}
    \item{na.action}{Function which indicates what should happen when
	the data contain NAs.}
    \item{partial}{Optional extra unpenalized terms in partial spline
	models.}
    \item{method}{Score used to drive the performance-oriented
	iteration.  Supported are \code{method="v"} for GCV,
	\code{method="m"} for GML, and \code{method="u"} for Mallow's CL.}
    \item{varht}{Dispersion parameter needed for \code{method="u"}.
	Ignored when \code{method="v"} or \code{method="m"} are
	specified.}
    \item{nu}{Inverse scale parameter in accelerated life model
        families.  Ignored for exponential families.}
    \item{prec}{Precision requirement for the iterations.}
    \item{maxiter}{Maximum number of iterations allowed for
	performance-oriented iteration, and for inner-loop multiple
	smoothing parameter selection when applicable.}
    \item{ext}{For cubic spline and linear spline marginals, this option
	specifies how far to extend the domain beyond the minimum and
	the maximum as a percentage of the range.  The default
	\code{ext=.05} specifies marginal domains of lengths 110 percent
	of their respective ranges.  Prediction outside of the domain
	will result in an error.  Ignored if \code{type="tp"} is
	specified.}
    \item{order}{For thin-plate spline marginals, this option specifies
	the order of the marginal penalties.  Ignored if
	\code{type="cubic"} or \code{type="linear"} are specified.}
}
\details{
    The models are fitted by penalized likelihood method through the
    performance-oriented iteration, as described in the reference cited
    below.

    Only one link is implemented for each \code{\link{family}}.  It is
    the logit link for \code{"binomial"}, and the log link for
    \code{"poisson"}, \code{"Gamma"}, and \code{"inverse.gaussian"}.
    For \code{"nbinomial"}, the working parameter is the logit of the
    probability \eqn{p}; see \code{\link{NegBinomial}}.  For
    \code{"weibull"}, \code{"lognorm"}, and \code{"loglogis"}, it is the
    location parameter for the log life time.

    For \code{family="binomial"}, \code{"poisson"}, \code{"nbinomial"},
    \code{"weibull"}, \code{"lognorm"}, and \code{"loglogis"}, the score
    driving the performance-oriented iteration defaults to
    \code{method="u"} with \code{varht=1}.  For \code{family="Gamma"}
    and \code{"inverse.gaussian"}, the default is \code{method="v"}.

    See \code{\link{ssanova}} for details and notes concerning smoothing
    spline ANOVA models.
}
\note{
    For \code{family="binomial"}, the response can be specified either
    as two columns of counts or as a column of sample proportions plus a
    column of total counts entered through the argument \code{weights},
    as in \code{\link{glm}}.

    For \code{family="nbinomial"}, the response may be specified as two
    columns with the second being the known sizes, or simply as a single
    column with the common unknown size to be estimated through the
    maximum likelihood method.

    For \code{family="weibull"}, \code{"lognorm"}, or \code{"loglogis"},
    the response consists of three columns, with the first giving the
    follow-up time, the second the censoring status, and the third the
    left-truncation time.  For data with no truncation, the third column
    can be omitted.
}
\value{
    \code{gssanova} returns a list object of \code{\link{class}}
    \code{"gssanova"} which inherits from the class \code{"ssanova"}.

    The method \code{\link{summary}} is used to obtain summaries of the
    fits.  The method \code{\link{predict}} can be used to evaluate the
    fits at arbitrary points, along with the standard errors to be used
    in Bayesian confidence intervals, both on the scale of the link.
    The methods \code{\link{residuals}} and \code{\link{fitted.values}}
    extract the respective traits from the fits.
}
\seealso{
    Methods \code{\link{predict.ssanova}},
    \code{\link{summary.gssanova}}, and \code{\link{fitted.gssanova}}.
}
\author{Chong Gu, \email{chong@stat.purdue.edu}}
\references{
    Gu, C. (1992), Cross-validating non Gaussian data. \emph{Journal
	of Computational and Graphical Statistics}, \bold{1}, 169-179.
}
\examples{
## Fit a cubic smoothing spline logistic regression model
test <- function(x)
        {.3*(1e6*(x^11*(1-x)^6)+1e4*(x^3*(1-x)^10))-2}
x <- (0:100)/100
p <- 1-1/(1+exp(test(x)))
y <- rbinom(x,3,p)
logit.fit <- gssanova(cbind(y,3-y)~x,family="binomial")
## The same fit
logit.fit1 <- gssanova(y/3~x,"binomial",weights=rep(3,101))
## Obtain estimates and standard errors on a grid
est <- predict(logit.fit,data.frame(x=x),se=TRUE)
## Plot the fit and the Bayesian confidence intervals
plot(x,y/3,ylab="p")
lines(x,p,col=1)
lines(x,1-1/(1+exp(est$fit)),col=2)
lines(x,1-1/(1+exp(est$fit+1.96*est$se)),col=3)
lines(x,1-1/(1+exp(est$fit-1.96*est$se)),col=3)
## Clean up
\dontrun{rm(test,x,p,y,logit.fit,logit.fit1,est)
dev.off()}
}
\keyword{models}
\keyword{regression}
\keyword{smooth}

\eof
\name{gssanova1}
\alias{gssanova1}
\title{Fitting Smoothing Spline ANOVA Models with Non Gaussian Responses}
\description{
    Fit smoothing spline ANOVA models to responses from selected
    exponential families with cubic spline, linear spline, or thin-plate
    spline marginals for numerical variables.  Factors are also
    accepted.  The symbolic model specification via \code{formula}
    follows the same rules as in \code{\link{lm}} and \code{\link{glm}}.
}
\usage{
gssanova1(formula, family, type="cubic", data=list(), weights, subset,
          offset, na.action=na.omit, partial=NULL, alpha=NULL, nu=NULL,
          id.basis=NULL, nbasis=NULL, seed=NULL, random=NULL,
          ext=.05,order=2)
}
\arguments{
    \item{formula}{Symbolic description of the model to be fit.}
    \item{family}{Description of the error distribution.  Supported
	are exponential families \code{"binomial"}, \code{"poisson"},
	\code{"Gamma"}, and \code{"nbinomial"}.  Also supported are
	accelerated life model families \code{"weibull"},
	\code{"lognorm"}, and \code{"loglogis"}.}
    \item{type}{Type of numerical marginals to be used.  Supported
	are \code{type="cubic"} for cubic spline marginals,
	\code{type="linear"} for linear spline marginals, and
	\code{type="tp"} for thin-plate spline marginals.}
    \item{data}{Optional data frame containing the variables in the
	model.}
    \item{weights}{Optional vector of weights to be used in the
	fitting process.}
    \item{subset}{Optional vector specifying a subset of observations
	to be used in the fitting process.}
    \item{offset}{Optional offset term with known parameter 1.}
    \item{na.action}{Function which indicates what should happen when
	the data contain NAs.}
    \item{partial}{Optional extra unpenalized terms in partial spline
	models.}
    \item{alpha}{Tuning parameter defining cross-validation; larger
        values yield smoother fits.  Defaults are \code{alpha=1} for
	\code{family="binomial"} and \code{alpha=1.4} for
	\code{family="poisson"} and \code{family="Gamma"}.}
    \item{nu}{Input for future support of accelerated life model
        families.}
    \item{id.basis}{Index designating selected "knots".}
    \item{nbasis}{Number of "knots" to be selected.  Ignored when
	\code{id.basis} is supplied.}
    \item{seed}{Seed for reproducible random selection of "knots".
	Ignored when \code{id.basis} is supplied.}
    \item{random}{Input for parametric random effects in nonparametric
        mixed-effect models.  See \code{\link{mkran}} for details.}
    \item{ext}{For cubic spline and linear spline marginals, this option
	specifies how far to extend the domain beyond the minimum and
	the maximum as a percentage of the range.  The default
	\code{ext=.05} specifies marginal domains of lengths 110 percent
	of their respective ranges.  Prediction outside of the domain
	will result in an error.  Ignored if \code{type="tp"} is
	specified.}
    \item{order}{For thin-plate spline marginals, this option specifies
	the order of the marginal penalties.  Ignored if
	\code{type="cubic"} or \code{type="linear"} are specified.}
}
\details{
    \code{gssanova1} implements an alternative approach to the fitting of
    \code{gssanova} models.  It works in some \eqn{q}-dimensional
    function space determined by a set of "knots" typically through
    random selection; the default dimension (\code{nbasis}) is set to be
    \eqn{q=10n^(2/9)}, adequate for cubic splines.  The algorithms are
    of the order \eqn{O(nq^2)}, scaling much better than the
    \eqn{O(n^3)} of \code{ssanova}; the memory requirements are
    \eqn{O(nq)} versus \eqn{O(n^2)}.

    \code{gssanova1} adopts direct cross-validation instead of the
    indirect cross-validation of \code{gssanova}.  Currently, only three
    families are supported, \code{"binomial"}, \code{"poisson"}, and
    \code{"Gamma"}.  Other families of \code{gssanova} shall be added in
    the future.

    Only one link is implemented for each \code{\link{family}}.  It is
    the logit link for \code{"binomial"}, and the log link for
    \code{"poisson"}, and \code{"Gamma"}.

    See \code{\link{ssanova}} for details and notes concerning smoothing
    spline ANOVA models.
}
\note{
    For \code{family="binomial"}, the response can be specified either
    as two columns of counts or as a column of sample proportions plus a
    column of total counts entered through the argument \code{weights},
    as in \code{\link{glm}}.
}
\value{
    \code{gssanova1} returns a list object of \code{\link{class}}
    \code{"gssanova1"} which inherits from the classes
    \code{"ssanova1"}, \code{"gssanova"}, and \code{"ssanova"}.

    The method \code{\link{summary}} is used to obtain summaries of the
    fits.  The method \code{\link{predict}} can be used to evaluate the
    fits at arbitrary points, along with the standard errors to be used
    in Bayesian confidence intervals, both on the scale of the link.
    The methods \code{\link{residuals}} and \code{\link{fitted.values}}
    extract the respective traits from the fits.
}
\seealso{
    \code{\link{gssanova}} and methods \code{\link{predict.ssanova1}},
    \code{\link{summary.gssanova1}}, and \code{\link{fitted.gssanova}}.
}
\author{Chong Gu, \email{chong@stat.purdue.edu}}
\references{
}
\examples{
## Fit a cubic smoothing spline logistic regression model
test <- function(x)
        {.3*(1e6*(x^11*(1-x)^6)+1e4*(x^3*(1-x)^10))-2}
x <- (0:100)/100
p <- 1-1/(1+exp(test(x)))
y <- rbinom(x,3,p)
logit.fit <- gssanova1(cbind(y,3-y)~x,family="binomial")
## The same fit
logit.fit1 <- gssanova1(y/3~x,"binomial",weights=rep(3,101),
                        id.basis=logit.fit$id.basis)
## Obtain estimates and standard errors on a grid
est <- predict(logit.fit,data.frame(x=x),se=TRUE)
## Plot the fit and the Bayesian confidence intervals
plot(x,y/3,ylab="p")
lines(x,p,col=1)
lines(x,1-1/(1+exp(est$fit)),col=2)
lines(x,1-1/(1+exp(est$fit+1.96*est$se)),col=3)
lines(x,1-1/(1+exp(est$fit-1.96*est$se)),col=3)

## Fit a mixed-effect logistic model
data(bacteriuria)
bact.fit <- gssanova1(infect~trt+time,family="binomial",data=bacteriuria,
                     id.basis=(1:820)[bacteriuria$id\%in\%c(3,38)],random=~1|id)
## Predict fixed effects
predict(bact.fit,data.frame(time=2:16,trt=as.factor(rep(1,15))),se=TRUE)
## Estimated random effects
bact.fit$b

## Clean up
\dontrun{rm(test,x,p,y,logit.fit,logit.fit1,est,bacteriuria,bact.fit)
dev.off()}
}
\keyword{models}
\keyword{regression}
\keyword{smooth}

\eof
\name{hzdrate.sshzd}
\alias{hzdrate.sshzd}
\alias{hzdcurve.sshzd}
\alias{survexp.sshzd}
\title{Evaluating Smoothing Spline Hazard Estimates}
\description{
    Evaluate smoothing spline hazard estimates by \code{sshzd}.
}
\usage{
hzdrate.sshzd(object, x, se=FALSE)
hzdcurve.sshzd(object, time, covariates=NULL, se=FALSE)
survexp.sshzd(object, time, covariates=NULL, start=0)
}
\arguments{
    \item{object}{Object of class \code{"sshzd"}.}
    \item{x}{Data frame or vector of points on which hazard is to be
      evaluated.}
    \item{se}{Flag indicating if standard errors are required.}
    \item{time}{Vector of time points.}
    \item{covariates}{Vector of covariate values.}
    \item{start}{Optional starting times of the intervals.}
}
\value{
    For \code{se=FALSE}, \code{hzdrate.sshzd} returns a vector of hazard
    evaluations.  For \code{se=TRUE}, \code{hzdrate.sshzd} returns a
    list consisting of the following components.
    \item{fit}{Vector of hazard evaluations.}
    \item{se.fit}{Vector of standard errors for log hazard.}
    
    For \code{se=FALSE}, \code{hzdcurve.sshzd} returns a vector or
    columns of hazard curve(s) evaluated on \code{time} points at the
    \code{covariates} values.  For \code{se=TRUE}, \code{hzdrate.sshzd}
    returns a list consisting of the following components.
    \item{fit}{Vector or columns of hazard curve(s).}
    \item{se.fit}{Vector or columns of standard errors for log hazard
      curve(s).}

    \code{survexp.sshzd} returns a vector of expected survivals, which
    are based on the cumulative hazards over the specified intervals.
}
\seealso{
    \code{\link{sshzd}}.
}
\keyword{models}
\keyword{smooth}
\keyword{survival}

\eof
\name{mkfun.poly}
\alias{mkfun.poly}
\alias{mkrk.linear}
\alias{mkrk.cubic}
\alias{mkphi.cubic}
\title{
    Crafting Building Blocks for Polynomial Splines
}
\description{
    Craft numerical functions to be used by \code{\link{mkterm.linear}},
    \code{\link{mkterm.cubic}} to assemble model terms.
}
\usage{
mkrk.linear(range)
mkrk.cubic(range)
mkphi.cubic(range)
}
\arguments{
    \item{range}{Numerical vector whose minimum and maximum specify the
	range on which the function to be crafted is defined.}
}
\value{
    A list of two components.
    \item{fun}{Function definition.}
    \item{env}{Portable local constants derived from the argument.}
}
\note{
    \code{mkrk.x} create a bivariate function
    \code{fun(x,y,env,outer=FALSE)}, where \code{x}, \code{y} are real
    arguments and local constants can be passed in through \code{env}.

    \code{mkphi.cubic} creates a univariate function
    \code{fun(x,nu=1,env)}.
}
\seealso{
    \code{\link{mkfun.tp}}, \code{\link{mkrk.factor}}.
}
\details{
    These are not to be called by the user.
}  
\keyword{internal}

\eof
\name{mkfun.tp}
\alias{mkfun.tp}
\alias{mkrk.tp}
\alias{mkrk.tp.p}
\alias{mkphi.tp}
\alias{mkphi.tp.p}
\title{
    Crafting Building Blocks for Thin-Plate Splines
}
\description{
    Craft numerical functions to be used by \code{\link{mkterm.tp}} to
    assemble model terms.
}
\usage{
mkrk.tp(dm,order,mesh,weight)
mkphi.tp(dm,order,mesh,weight)

mkrk.tp.p(dm,order)
mkphi.tp.p(dm,order)
}
\arguments{
    \item{dm}{Dimension of the variable \eqn{d}.}
    \item{order}{Order of the differential operator \eqn{m}.}
    \item{mesh}{Normalizing mesh.}
    \item{weight}{Normalizing weights.}
}
\details{
    These are not to be called by the user.

    Thin-plate splines are defined for \eqn{2m>d}.

    \code{mkrk.tp.p} generates the pseudo kernel, and \code{mkphi.tp.p}
    generates the \eqn{(m+d-1)!/d!/(m-1)!} lower order polynomials with
    total order less than \eqn{m}.

    \code{mkphi.tp} generates normalized lower order polynomials
    orthonormal w.r.t. a norm specified by \code{mesh} and \code{weight}
    as described in the reference, and \code{mkrk.tp} conditions the
    pseudo kernel to generate the reproducing kernel orthogonal to the
    lower order polynomials w.r.t. the norm.
}
\value{
    A list of two components.
    \item{fun}{Function definition.}
    \item{env}{Portable local constants derived from the arguments.}
}
\note{
    \code{mkrk.tp} creates a bivariate function
    \code{fun(x,y,env,outer=FALSE)}, where \code{x}, \code{y} are real
    arguments and local constants can be passed in through \code{env}.

    \code{mkphi.tp} creates a collection of univariate functions
    \code{fun(x,nu,env)}, where \code{x} is the argument and \code{nu}
    is the index.
}
\references{
    Gu, C. and Wahba, G. (1993), Semiparametric analysis of variance
    with tensor product thin plate splines.  \emph{Journal of the Royal
	Statistical Society Ser. B}, \bold{55}, 353--368.
}
\seealso{
    \code{\link{mkfun.poly}}, \code{\link{mkrk.factor}}.
}
\keyword{internal}

\eof
\name{mkran}
\alias{mkran}
\title{
    Generating Random Effects in Mixed-Effect Models
}
\description{
    Generate entries representing random effects in mixed-effect models.
}
\usage{
mkran(formula, data)
}
\arguments{
    \item{formula}{Symbolic description of the random effects.}
    \item{data}{Data frame containing the variables in the model.}
}
\details{
    This function generates random effects terms from simple grouping
    variables, for use in nonparametric mixed-effect models as described
    in Gu and Ma (2003a, b).  The syntax of the formula resembles that
    of similar utilities for linear and nonlinear mixed-effect models,
    as described in Pinheiro and Bates (2000).

    Currently, \code{mkran} takes only two kinds of formulas,
    \code{~1|grp2} or \code{~grp1|grp2}.  Both \code{grp1} and
    \code{grp2} should be factors, and for the second formula, the
    levels of \code{grp2} should be nested under those of \code{grp1}.

    The Z matrix is determined by \code{grp2}.  When observations are
    ordered according to the levels of \code{grp2}, the Z matrix is
    block diagonal of 1 vectors.

    The Sigma matrix is diagonal.  For \code{~1|grp2}, it has one tuning
    parameter.  For \code{~grp1|grp2}, the number of parameters equals
    the number of levels of \code{grp1}, with each parameter shared by
    the \code{grp2} levels nested under the same \code{grp1} level.
}
\value{
    A list of three components.
    \item{z}{Z matrix.}
    \item{sigma}{Sigma matrix to be evaluated through
        \code{sigma$fun(para,sigma$env)}.}
    \item{init}{Initial parameter values.}
}
\note{
    One may pass a formula or a list to the argument \code{random} in
    calls to \code{\link{ssanova1}} or\code{\link{gssanova1}} to fit
    nonparametric mixed-effect models.  A formula will be converted to a
    list using \code{mkran}.  A list should be of the same form as the
    value of \code{mkran}.
}
\author{Chong Gu, \email{chong@stat.purdue.edu}}
\references{
    Gu and Ma (2003a), \emph{Optimal Smoothing in Nonparametric
    Mixed-Effect Models}.  Available at
    \url{http://stat.purdue.edu/~chong/manu.html}.

    Gu and Ma (2003b), \emph{Generalized Nonparametric Mixed-Effect
    Models: Computation and Smoothing Parameter Selection}.  Available
    at \url{http://stat.purdue.edu/~chong/manu.html}.

    Pinheiro and Bates (2000), \emph{Mixed-Effects Models in S and
    S-PLUS}.  New York: Springer-Verlag.
}
\examples{
## Toy data
test <- data.frame(grp=as.factor(rep(1:2,c(2,3))))
## First formula
ran.test <- mkran(~1|grp,test)
ran.test$z
ran.test$sigma$fun(2,ran.test$sigma$env) # diag(10^(-2),2)
## Second formula
ran.test <- mkran(~grp|grp,test)
ran.test$z
ran.test$sigma$fun(c(1,2),ran.test$sigma$env) # diag(10^(-1),10^(-2))
## Clean up
\dontrun{rm(test,ran.test)}
}
\keyword{models}
\keyword{regression}

\eof
\name{mkrk.factor}
\alias{mkrk.factor}
\alias{mkrk.nominal}
\alias{mkrk.ordinal}
\title{
    Crafting Building Blocks for Discrete Splines
}
\description{
    Craft numerical functions to be used by \code{mkterm.x} to assemble
    model terms involving factors.
}
\usage{
mkrk.nominal(levels)
mkrk.ordinal(levels)
}
\arguments{
    \item{levels}{Levels of the factor.}
}
\details{
    These are not to be called by the user.

    For a nominal factor with levels \eqn{1,2,\dots,k}, the level means
    \eqn{f(i)} will be shrunk towards each other through a penalty
    proportional to
    \deqn{(f(1)-f(.))^2+\dots+(f(k)-f(.))^2}
    where \eqn{f(.)=(f(1)+\dots+f(k))/k}.

    For a ordinal factor with levels \eqn{1<2<\dots<k}, the level means
    \eqn{f(i)} will be shrunk towards each other through a penalty
    proportional to
    \deqn{(f(1)-f(2))^2+\dots+(f(k-1)-f(k))^2}
}
\value{
    A list of two components.
    \item{fun}{Function definition.}
    \item{env}{Portable local constants derived from the arguments.}
}
\note{
    \code{mkrk.x} create a bivariate function
    \code{fun(x,y,env,outer=FALSE)}, where \code{x}, \code{y} are real
    arguments and local constants can be passed in through \code{env}.
}
\seealso{
    \code{\link{mkterm.ssanova}}, \code{\link{mkfun.poly}},
    \code{\link{mkfun.tp}}.
}
\keyword{internal}

\eof
\name{mkterm.ssanova}
\alias{mkterm.ssanova}
\alias{mkterm.linear}
\alias{mkterm.linear1}
\alias{mkterm.cubic}
\alias{mkterm.cubic1}
\alias{mkterm.tp}
\title{
    Assembling Model Terms for Smoothing Spline ANOVA Models
}
\description{
    Assemble numerical functions for calculating model terms in a
    Smoothing Spline ANOVA Model.
}
\usage{
mkterm.linear(mf, ext)
mkterm.linear1(mf, range)
mkterm.cubic(mf, ext)
mkterm.cubic1(mf, range)
mkterm.tp(mf, order, mesh, weight)
}
\arguments{
    \item{mf}{Model frame of the model formula.}
    \item{ext}{Size of the "buffer zone" beyond the data range.}
    \item{range}{Data frame specifying domain range.}
    \item{order}{Order of the differential operator.}
    \item{mesh}{Normalizing mesh.}
    \item{weight}{Normalizing weights.}
}
\details{
    These are not to be called by the user.

    For polynomial splines, \code{ext} specifies how far to go beyond
    the data range percentage wise.  For example, if the minimum and
    maximum values of a variable in \code{mf} is 0 and 1 and
    \code{ext=.05}, then the marginal domain on which the model is
    defined would be \eqn{[-.95,1.05]}.

    See \code{\link{mkfun.tp}} for \code{order}, \code{mesh},
    \code{weight}.
}
\value{
    A list object with a component \code{labels} containing the labels
    of all model terms.  For each of the model terms, there is a
    component holding the numerical functions for calculating the
    unpenalized and penalized parts within the term.
}
\note{
    The numerical functions are assembled using building blocks crafted
    by \code{\link{mkfun.poly}}, \code{\link{mkfun.tp}},
    \code{\link{mkrk.factor}}.
}
\keyword{internal}

\eof
\name{nlm0}
\alias{nlm0}
\title{Minimizing Univariate Functions on Finite Intervals}
\description{
   Minimize univariate functions on finite intervals using 3-point
   quadratic fit, with golden-section safe-guard.
}
\usage{
nlm0(fun,range,prec=1e-7)
}
\arguments{
    \item{fun}{Function to be minimized.}
    \item{range}{Interval on which the function to be minimized.}
    \item{prec}{Desired precision of the solution.}
}
\value{
    \code{nlm0} returns a list object with the following components.
    \item{estimate}{Minimizer.}
    \item{minimum}{Minimum.}
    \item{evaluations}{Number of function evaluations.}
}
\keyword{math}

\eof
\name{nox}
\alias{nox}
\title{NOx in Engine Exhaust}
\description{
    Data from an experiment in which a single-cylinder engine was run
    with ethanol to see how the NOx concentration in the exhaust
    depended on the compression ratio and the equivalence ratio.
}
\usage{data(nox)}
\format{
    A data frame containing 88 observations on the following variables.
    \tabular{ll}{
	\code{nox} \tab NOx concentration in exhaust.\cr
	\code{comp} \tab Compression ratio.\cr
	\code{equi} \tab Equivalence ratio.
    }
}
\source{
    Brinkman, N. D. (1981), Ethanol fuel -- a single-cylinder engine
    study of efficiency and exhaust emissions.  \emph{SAE Transactions},
    \bold{90}, 1410--1424.
}
\references{
    Cleveland, W. S. and Devlin, S. J. (1988), Locally weighted
    regression: An approach to regression analysis by local fitting.
    \emph{Journal of the American Statistical Association}, \bold{83},
    596--610.

    Breiman, L. (1991), The pi method for estimating multivariate
    functions from noisy data.  \emph{Technometrics}, \bold{33},
    125--160. 
}
\keyword{datasets}

\eof
\name{ozone}
\alias{ozone}
\title{Ozone Concentration in Los Angeles Basin}
\description{
    Daily measurements of ozone concentration and eight meteorological
    quantities in the Los Angeles basin for 330 days of 1976.
}
\usage{data(ozone)}
\format{
    A data frame containing 330 observations on the following variables.
    \tabular{ll}{
	\code{upo3} \tab Upland ozone concentration, in ppm.\cr
	\code{vdht} \tab Vandenberg 500 millibar height, in meters.\cr
	\code{wdsp} \tab Wind speed, in miles per hour.\cr
	\code{hmdt} \tab Humidity.\cr
	\code{sbtp} \tab Sandburg Air Base temperature, in Celsius.\cr
	\code{ibht} \tab Inversion base height, in foot.\cr
	\code{dgpg} \tab Dagget pressure gradient, in mmhg.\cr
	\code{ibtp} \tab Inversion base temperature, in Fahrenheit.\cr
	\code{vsty} \tab Visibility, in miles.\cr
	\code{day} \tab Calendar day, between 1 and 366.
    }
}
\source{
    Unknown.
}
\references{
    Breiman, L. and Friedman, J. H. (1985), Estimating optimal
    transformations for multiple regression and correlation.
    \emph{Journal of the American Statistical Association}, \bold{80},
    580--598.

    Hastie, T. and Tibshirani, R. (1990), \emph{Generalized Additive
    Models}. Chapman and Hall.
}
\keyword{datasets}

\eof
\name{predict.ssanova}
\alias{predict.ssanova}
\alias{predict.ssanova1}
\title{Predicting from Smoothing Spline ANOVA Fits}
\description{
    Evaluate terms in a smoothing spline ANOVA fit at arbitrary points.
    Standard errors of the terms can be requested for use in
    constructing Bayesian confidence intervals.
}
\usage{
predict.ssanova(object, newdata, se.fit=FALSE,
                include=object$terms$labels, ...)
predict.ssanova1(object, newdata, se.fit=FALSE,
                 include=object$terms$labels, ...)
}
\arguments{
    \item{object}{Object of class inheriting from \code{"ssanova"}.}
    \item{newdata}{Data frame or model frame in which to predict.}
    \item{se.fit}{Flag indicating if standard errors are required.}
    \item{include}{List of model terms to be included in the
	prediction.  The \code{partial} and \code{offset} terms, if
	present, are to be specified by \code{"partial"} and
	\code{"offset"}, respectively.}
    \item{...}{Ignored.}
}
\value{
    For \code{se.fit=FALSE}, \code{predict.ssanova} returns a vector of
    the evaluated fit.

    For \code{se.fit=TRUE}, \code{predict.ssanova} returns a list
    consisting of the following components.
    \item{fit}{Vector of evaluated fit.}
    \item{se.fit}{Vector of standard errors.}
}
\note{
    To supply the partial terms for partial spline models, add a
    component \code{partial=I(...)} in \code{newdata}; the "as is"
    function \code{I(...)} is necessary when \code{partial} has more
    than one column.

    For mixed-effect models through \code{\link{ssanova1}} or
    \code{\link{gssanova1}}, the Z matrix is set to 0 if not supplied.
    To supply the Z matrix, add a component \code{random=I(...)} in
    \code{newdata}.
}
\seealso{
    Fitting functions \code{\link{ssanova}}, \code{\link{ssanova}} and
    methods \code{\link{summary.ssanova}}, \code{\link{summary.gssanova}},
    \code{\link{fitted.ssanova}}.
}
\author{Chong Gu, \email{chong@stat.purdue.edu}}
\references{
    Gu, C. and Wahba, G. (1993), Smoothing spline ANOVA with
    component-wise Bayesian "confidence intervals".  \emph{Journal
	of Computational and Graphical Statistics}, \bold{2}, 97--117.
}
\examples{
## THE FOLLOWING EXAMPLE IS TIME-CONSUMING
\dontrun{
## Fit a model with thin-plate marginals, where geog is 2-D
data(LakeAcidity)
fit <- ssanova(ph~log(cal)*geog,"tp",LakeAcidity)
## Obtain estimates and standard errors on a grid
new <- data.frame(cal=1,geog=I(matrix(0,1,2)))
new <- model.frame(~log(cal)+geog,new)
predict(fit,new,se=TRUE)
## Evaluate the geog main effect
predict(fit,new,se=TRUE,inc="geog")
## Evaluate the sum of the geog main effect and the interaction
predict(fit,new,se=TRUE,inc=c("geog","log(cal):geog"))
## Evaluate the geog main effect on a grid
grid <- seq(-.04,.04,len=21)
new <- model.frame(~geog,list(geog=cbind(rep(grid,21),rep(grid,rep(21,21)))))
est <- predict(fit,new,se=TRUE,inc="geog")
## Plot the fit and standard error
par(pty="s")
contour(grid,grid,matrix(est$fit,21,21),col=1)
contour(grid,grid,matrix(est$se,21,21),add=TRUE,col=2)
## Clean up
rm(LakeAcidity,fit,new,grid,est)
dev.off()
}
}
\keyword{models}
\keyword{regression}
\keyword{smooth}

\eof
\name{print.ssanova}
\alias{print.gssanova1}
\alias{print.ssanova}
\alias{print.ssanova1}
\alias{print.ssden}
\alias{print.sshzd}
\alias{print.summary.ssanova}
\alias{print.summary.gssanova}
\alias{print.summary.gssanova1}
\title{Print Functions for Smoothing Spline ANOVA Models}
\description{
    Print functions for Smoothing Spline ANOVA models.
}
\usage{
print.gssanova1(x, ...)
print.ssanova(x, ...)
print.ssanova1(x, ...)
print.ssden(x, ...)
print.sshzd(x, ...)
print.summary.ssanova(x, digits=6, ...)
print.summary.gssanova(x, digits=6, ...)
print.summary.gssanova1(x, digits=6, ...)
}
\arguments{
    \item{x}{Object of class \code{ssanova}, \code{summary.ssanova},
        \code{summary.gssanova}, or \code{ssden}.}
    \item{digits}{Number of significant digits to be printed in
	values.}
    \item{...}{Ignored.}
}
\seealso{
    \code{\link{ssanova}}, \code{\link{gssanova}},
    \code{\link{summary.ssanova}}, \code{\link{summary.gssanova}},
    \code{\link{ssden}}, \code{\link{sshzd}}.
}
\keyword{smooth}
\keyword{models}

\eof
\name{project}
\alias{project}
\alias{project.ssanova1}
\alias{project.gssanova1}
\alias{project.ssden}
\alias{project.sshzd}
\title{Projecting Smoothing Spline ANOVA Fits for Model Diagnostics}
\description{
    Calculate Kullback-Leibler projection of smoothing spline ANOVA fits
    for Model Diagnostics.
}
\usage{
project(object, ...)
project.ssanova1(object, include, ...)
project.gssanova1(object, include, ...)
project.ssden(object, include, mesh=FALSE, ...)
project.sshzd(object, include, mesh=FALSE, ...)
}
\arguments{
    \item{object}{Object of class \code{"ssanova1"}, \code{"gssanova1"},
        \code{"ssden"}, or \code{"sshzd"}.}
    \item{...}{Additional arguments.  Ignored in \code{project.x}.}
    \item{include}{List of model terms to be included in the reduced
        model space.  The \code{partial} and \code{offset} terms, if
	present, are to be specified by \code{"partial"} and
	\code{"offset"}, respectively.}
    \item{mesh}{Flag indicating whether to return evaluations of the
        projection.}
}
\value{
    The functions return a list consisting of the following components.
    \item{ratio}{KL(fit0,fit1)/KL(fit0,null); the smaller the value, the
        more feasible the reduced model is.}
    \item{kl}{KL(fit0,fit1).}

    For regression fits, the list also contains the following component.
    \item{check}{KL(fit0,fit1)/KL(fit0,null)+KL(fit1,null)/KL(fit0,null);
        a value closer to 1 is preferred.}

    For density and hazard fits, the list may contain the following
    optional component.
    \item{mesh}{The evaluations of the projection.}
}
\details{
    The entropy KL(fit0,null) can be decomposed as the sum of
    KL(fit0,fit1) and KL(fit1,null), where fit0 is the fit to be
    projected, fit1 is the projection in the reduced model space, and
    null is the constant fit.  The ratio KL(fit0,fit1)/KL(fit0,null)
    serves as a diagnostic of the feasibility of the reduced model.

    For regression fits, smoothness safe-guard is used to prevent
    interpolation, and KL(fit0,fit1)+KL(fit1,null) may not match
    KL(fit0,null) perfectly.

    For mixed-effect models from \code{ssanova1} and \code{gssanova1},
    the estimated random effects are treated as offset.
}
\author{Chong Gu, \email{chong@stat.purdue.edu}}
\references{
    Gu, C. (2003), \emph{Model Diagnostics for Smoothing Spline ANOVA
    Models}.  Available at
    \url{http://stat.purdue.edu/~chong/manu.html}.
}
\seealso{
    Fitting functions \code{\link{ssanova1}}, \code{\link{gssanova1}},
    \code{\link{ssden}}, and \code{\link{sshzd}}.
}
\keyword{models}
\keyword{smooth}
\keyword{htest}

\eof
\name{rkpk}
\alias{sspreg}
\alias{mspreg}
\alias{getcrdr}
\alias{getsms}
\alias{sspregpoi}
\alias{mspregpoi}
\title{Interface to RKPACK}
\description{
    Call RKPACK routines for numerical calculations for fitting and
    predicting from Smoothing Spline ANOVA models.
}
\usage{
sspreg(s, q, y, method="v", varht=1)
mspreg(s, q, y, method="v", varht=1, prec=1e-7, maxiter=30)
sspregpoi(family, s, q, y, wt, offset, method="u",
          varht=1, nu, prec=1e-7, maxiter=30)
mspregpoi(family, s, q, y, wt, offset, method="u",
          varht=1, nu, prec=1e-7, maxiter=30)
getcrdr(obj, r)
getsms(obj)
}
\details{
    \code{sspreg} is used by \code{\link{ssanova}} to fit Gaussian
    models with a single smoothing parameter.  \code{mspreg} is used to
    fit Gaussian models with multiple single smoothing parameters.

    \code{sspregpoi} is used by \code{\link{gssanova}} to fit non
    Gaussian models with a single smoothing parameter.  \code{mspregpoi}
    is used to fit non Gaussian models with multiple single smoothing
    parameters.

    \code{getcrdr} and \code{getsms} are used by
    \code{\link{predict.ssanova}} to calculate standard errors of the
    fitted terms.
}
\arguments{
    \item{s}{Design matrix of unpenalized terms.}
    \item{q}{Penalty matrices of penalized terms.}
    \item{y}{Model response.}
    \item{method}{Method for smoothing parameter selection.}
    \item{varht}{Assumed dispersion parameter, needed only for
	\code{method="u"}.}
    \item{prec}{Precision requirement for iterations.}
    \item{maxiter}{Maximum number of iterations allowed.}
    \item{family}{Error family.}	
    \item{wt}{Model weights.}
    \item{offset}{Model offset.}
    \item{obj}{Object returned from a call to \code{sspreg},
      \code{mspreg}, \code{sspregpoi}, or \code{mspregpoi}.}
    \item{nu}{Optional argument for nbinomial, weibull, lognorm, and
      loglogis families.}
    \item{r}{Inputs for standard error calculation.}
}
\references{
    Gu, C. (1989), RKPACK and its applications: Fitting smoothing spline
    models.  In \emph{ASA Proceedings of Statistical Computing Section},
    pp. 42--51.
}
\keyword{smooth}

\eof
\name{rkpk1}
\alias{sspreg1}
\alias{mspreg1}
\alias{sspngreg1}
\alias{mspngreg1}
\alias{ngreg1}
\alias{ngreg.proj}
\title{Numerical Engine for ssanova1 and gssanova1}
\description{
    Calculate penalized least squares regression estimates via the
    normal equation and evaluate the GCV, GML, or Mallows' CL scores, as
    implemented in the RATFOR routine \code{reg.r}, and minimize the
    cross-validation score using \code{\link{nlm}}.
}
\usage{
sspreg1(s,r,q,y,method,alpha,varht,random)
mspreg1(s,r,q,y,method,alpha,varht,random)

sspngreg1(family,s,r,q,y,wt,offset,alpha,nu,random)
mspngreg1(family,s,r,q,y,wt,offset,alpha,nu,random)
ngreg1(dc,family,sr,q,y,wt,offset,nu,alpha)

ngreg.proj(dc,family,sr,q,y0,wt,offset,nu)
}
\details{
    \code{sspreg1} is used by \code{\link{ssanova1}} to compute
    regression estimates with a single smoothing parameter.
    \code{mspreg1} is used by \code{\link{ssanova1}} to compute
    regression estimates with multiple smoothing parameters.

    \code{ssngpreg1} is used by \code{\link{gssanova1}} to compute
    non-Gaussian regression estimates with a single smoothing
    parameter.  \code{mspngreg1} is used by \code{\link{gssanova1}} to
    compute non-Gaussian regression estimates with multiple smoothing
    parameters.  \code{ngreg1} is used by \code{ssngpreg1} and
    \code{mspngreg1} to perform Newton iteration with fixed smoothing
    parameters and to calculate cross-validation scores on return.

    \code{ngreg.proj} is used by \code{project.gssanova1} to calculate
    Kullback-Leibler projection for non-Gaussian regression.
}
\arguments{
    \item{family}{Description of the error distribution.  Supported
	are exponential families \code{"binomial"}, \code{"poisson"},
	\code{"Gamma"}, and \code{"nbinomial"}.  Also supported are
	accelerated life model families \code{"weibull"},
	\code{"lognorm"}, and \code{"loglogis"}.}
    \item{s}{Unpenalized terms evaluated at data points.}
    \item{r}{Basis of penalized terms evaluated at data points.}
    \item{q}{Penalty matrix.}
    \item{y}{Response vector.}
    \item{wt}{Model weights.}
    \item{offset}{Model offset.}
    \item{method}{\code{"v"} for GCV, \code{"m"} for GML, or \code{"u"}
        for Mallows' CL.}
    \item{alpha}{Parameter modifying GCV or Mallows' CL scores for
        smoothing parameter selection.}
    \item{nu}{Optional argument for future support of nbinomial,
      weibull, lognorm, and loglogis families.}
    \item{varht}{External variance estimate needed for \code{method="u"}.}
    \item{random}{Input for parametric random effects in nonparametric
        mixed-effect models.}

    \item{dc}{Coefficients of fits.}
    \item{sr}{\code{cbind(s,r)}.}
    \item{y0}{Components of the fit to be projected.}
}
\references{
    Kim, Y.-J. and Gu, C. (2002) \emph{Penalized Least Squares
    Regression: Fast Computation via Efficient Approximation}.
    Available at \url{http://stat.purdue.edu/~chong/manu.html}.
}
\keyword{smooth}

\eof
\name{smolyak}
\alias{smolyak.quad}
\alias{smolyak.size}
\title{Generating Smolyak Cubature}
\description{
    Generate Smolyak cubatures using C routines modified from
    \code{smolyak.c} found in Knut Petras' SMOLPACK.
}
\usage{
smolyak.quad(d,k)

smolyak.size(d,k)
}
\arguments{
    \item{d}{Dimension of unit cube.}
    \item{k}{Depth of algorithm.}
}
\value{
    \code{smolyak.quad} returns a list object with the following
    components.
    \item{pt}{Quadrature nodes in rows of matrix.}
    \item{wt}{Quadrature weights.}

    \code{smolyak.size} returns an integer.
}
\details{
    \code{smolyak.quad} and \code{smolyak.size} concern the delayed
    Smolyak cubature.
}
\keyword{math}

\eof
\name{ssanova}
\alias{ssanova}
\title{Fitting Smoothing Spline ANOVA Models}
\description{
    Fit smoothing spline ANOVA models with cubic spline, linear spline,
    or thin-plate spline marginals for numerical variables.  Factors are
    also accepted.  The symbolic model specification via \code{formula}
    follows the same rules as in \code{\link{lm}}.
}
\usage{
ssanova(formula, type="cubic", data=list(), weights, subset,
        offset, na.action=na.omit, partial=NULL, method="v",
        varht=1, prec=1e-7, maxiter=30, ext=.05, order=2)
}
\arguments{
    \item{formula}{Symbolic description of the model to be fit.}
    \item{type}{Type of numerical marginals to be used.  Supported are
	\code{type="cubic"} for cubic spline marginals,
	\code{type="linear"} for linear spline marginals, and
	\code{type="tp"} for thin-plate spline marginals.}
    \item{data}{Optional data frame containing the variables in the
	model.}
    \item{weights}{Optional vector of weights to be used in the
	fitting process.}
    \item{subset}{Optional vector specifying a subset of observations
	to be used in the fitting process.}
    \item{offset}{Optional offset term with known parameter 1.}
    \item{na.action}{Function which indicates what should happen when
	the data contain NAs.}
    \item{partial}{Optional extra unpenalized terms in partial spline
        models.}
    \item{method}{Method for smoothing parameter selection.  Supported
	are \code{method="v"} for GCV, \code{method="m"} for GML (REML),
	and \code{method="u"} for Mallow's CL.}
    \item{varht}{External variance estimate needed for
	\code{method="u"}.  Ignored when \code{method="v"} or
	\code{method="m"} are specified.}
    \item{prec}{Precision requirement in the iteration for multiple
	smoothing parameter selection.  Ignored when only one smoothing
	parameter is involved.}
    \item{maxiter}{Maximum number of iterations allowed for multiple
	smoothing parameter selection.  Ignored when only one smoothing
	parameter is involved.}
    \item{ext}{For cubic spline and linear spline marginals, this option
	specifies how far to extend the domain beyond the minimum and
	the maximum as a percentage of the range.  The default
	\code{ext=.05} specifies marginal domains of lengths 110 percent
	of their respective ranges.  Prediction outside of the domain
	will result in an error.  Ignored if \code{type="tp"} is
	specified.}
    \item{order}{For thin-plate spline marginals, this option specifies
	the order of the marginal penalties.  Ignored if
	\code{type="cubic"} or \code{type="linear"} are specified.}
}
\details{
    \code{ssanova} and the affiliated \code{\link{methods}} provide a
    front end to RKPACK, a collection of RATFOR routines for structural
    multivariate nonparametric regression via the penalized least
    squares method.  The algorithms implemented in RKPACK are of the
    orders \eqn{O(n^3)} in execution time and \eqn{O(n^2)} in memory
    requirement.  The constants in front of the orders vary with the
    complexity of the model to be fit.

    The model specification via \code{formula} is intuitive.  For
    example, \code{y~x1*x2} yields a model of the form
    \deqn{
	y = c + f_{1}(x1) + f_{2}(x2) + f_{12}(x1,x2) + e
    }
    with the terms denoted by \code{"1"}, \code{"x1"}, \code{"x2"}, and
    \code{"x1:x2"}.  Through the specifications of the side conditions,
    these terms are uniquely defined.  In the current implementation,
    \eqn{f_{1}} and \eqn{f_{12}} integrate to \eqn{0} on the \code{x1}
    domain for cubic spline and linear spline marginals, and add to
    \eqn{0} over the \code{x1} (marginal) sampling points for thin-plate
    spline marginals.

    The penalized least squares problem is equivalent to a certain
    empirical Bayes model or a mixed effect model, and the model terms
    themselves are generally sums of finer terms of two types, the
    unpenalized terms (fixed effects) and the penalized terms (random
    effects).  Attached to every penalized term there is a smoothing
    parameter, and the model complexity is largely determined by the
    number of smoothing parameters.

    The method \code{predict} can be used to evaluate the sum of
    selected or all model terms at arbitrary points within the domain,
    along with standard errors derived from a certain Bayesian
    calculation.  The method \code{summary} has a flag to request
    diagnostics for the practical identifiability and significance of
    the model terms.
}
\note{
    The independent variables appearing in \code{formula} can be
    multivariate themselves.  In particular,
    \code{ssanova(y~x,"tp",order=order)} can be used to fit ordinary
    thin-plate splines in any dimension, of any order permissible, and
    with standard errors available for Bayesian confidence intervals.
    Note that thin-plate splines reduce to polynomial splines in one
    dimension.

    For univariate marginals, the additive models using
    \code{type="cubic"} and \code{type="tp"} yield identical fit through
    different internal makes.  For example,
    \code{ssanova(y~x1+x2,"cubic")} and \code{ssanova(y~x1+x2,"tp")}
    yield the same fit.  The same is not true for models with
    interactions, however.
    
    Mathematically, the domain (through \code{ext} for
    \code{type="cubic"}) or the order (through \code{order} for
    \code{type="tp"}) could be specified individually for each of the
    variables.  Such flexibility is not provided in our implementation,
    however, as it would be more a source for confusion than a practical
    utility.
}
\section{Factors}{
    Factors are accepted as predictors.  When a factor has 3 or more
    levels, all terms involving it are treated as penalized terms, with
    the "level means" being shrunk towards each other.  The shrinking is
    done differently for nominal and ordinal factors; see
    \code{\link{mkrk.factor}} for details.
}
\value{
    \code{ssanova} returns a list object of \code{\link{class} "ssanova"}.

    The method \code{\link{summary}} is used to obtain summaries of the
    fits.  The method \code{\link{predict}} can be used to evaluate the
    fits at arbitrary points, along with the standard errors to be used
    in Bayesian confidence intervals.  The methods
    \code{\link{residuals}} and \code{\link{fitted.values}} extract the
    respective traits from the fits.
}
\seealso{
    Methods \code{\link{predict.ssanova}},
    \code{\link{summary.ssanova}}, and \code{\link{fitted.ssanova}}.
}
\author{Chong Gu, \email{chong@stat.purdue.edu}}
\references{
    Gu, C. (2002), \emph{Smoothing Spline ANOVA Models}.  New York:
    Springer-Verlag.
    
    Wahba, G. (1990), \emph{Spline Models for Observational Data}.
    Philadelphia: SIAM.
}
\examples{
## Fit a cubic spline
x <- runif(100); y <- 5 + 3*sin(2*pi*x) + rnorm(x)
cubic.fit <- ssanova(y~x,method="m")
## The same fit with different internal makes
tp.fit <- ssanova(y~x,"tp",method="m")
## Obtain estimates and standard errors on a grid
new <- data.frame(x=seq(min(x),max(x),len=50))
est <- predict(cubic.fit,new,se=TRUE)
## Plot the fit and the Bayesian confidence intervals
plot(x,y,col=1); lines(new$x,est$fit,col=2)
lines(new$x,est$fit+1.96*est$se,col=3)
lines(new$x,est$fit-1.96*est$se,col=3)
## Clean up
\dontrun{rm(x,y,cubic.fit,tp.fit,new,est)
dev.off()}

## Fit a tensor product cubic spline
data(nox)
nox.fit <- ssanova(log10(nox)~comp*equi,data=nox)
## Fit a spline with cubic and nominal marginals
nox$comp<-as.factor(nox$comp)
nox.fit.n <- ssanova(log10(nox)~comp*equi,data=nox)
## Fit a spline with cubic and ordinal marginals
nox$comp<-as.ordered(nox$comp)
nox.fit.o <- ssanova(log10(nox)~comp*equi,data=nox)
## Clean up
\dontrun{rm(nox,nox.fit,nox.fit.n,nox.fit.o)}
}
\keyword{smooth}
\keyword{models}
\keyword{regression}

\eof
\name{ssanova1}
\alias{ssanova1}
\title{Fitting Smoothing Spline ANOVA Models}
\description{
    Fit smoothing spline ANOVA models with cubic spline, linear spline,
    or thin-plate spline marginals for numerical variables.  Factors are
    also accepted.  The symbolic model specification via \code{formula}
    follows the same rules as in \code{\link{lm}}.
}
\usage{
ssanova1(formula, type="cubic", data=list(), weights, subset,
         offset, na.action=na.omit, partial=NULL, method="v",
         alpha=1.4, varht=1, id.basis=NULL, nbasis=NULL, seed=NULL,
         random=NULL, ext=.05, order=2)
}
\arguments{
    \item{formula}{Symbolic description of the model to be fit.}
    \item{type}{Type of numerical marginals to be used.  Supported are
	\code{type="cubic"} for cubic spline marginals,
	\code{type="linear"} for linear spline marginals, and
	\code{type="tp"} for thin-plate spline marginals.}
    \item{data}{Optional data frame containing the variables in the
	model.}
    \item{weights}{Optional vector of weights to be used in the
	fitting process.}
    \item{subset}{Optional vector specifying a subset of observations
	to be used in the fitting process.}
    \item{offset}{Optional offset term with known parameter 1.}
    \item{na.action}{Function which indicates what should happen when
	the data contain NAs.}
    \item{partial}{Optional extra unpenalized terms in partial spline
	models.}
    \item{method}{Method for smoothing parameter selection.  Supported
	are \code{method="v"} for GCV, \code{method="m"} for GML (REML),
	and \code{method="u"} for Mallows' CL.}
    \item{alpha}{Parameter modifying GCV or Mallows' CL; larger absolute
        values yield smoother fits; negative value invokes a stable and
	more accurate GCV/CL evaluation algorithm but may take two to
	five times as long.  Ignored when \code{method="m"} are
	specified.}
    \item{varht}{External variance estimate needed for
	\code{method="u"}.  Ignored when \code{method="v"} or
	\code{method="m"} are specified.}
    \item{id.basis}{Index designating selected "knots".}
    \item{nbasis}{Number of "knots" to be selected.  Ignored when
	\code{id.basis} is supplied.}
    \item{seed}{Seed for reproducible random selection of "knots".
	Ignored when \code{id.basis} is supplied.}
    \item{random}{Input for parametric random effects in nonparametric
        mixed-effect models.  See \code{\link{mkran}} for details.}
    \item{ext}{For cubic spline and linear spline marginals, this option
	specifies how far to extend the domain beyond the minimum and
	the maximum as a percentage of the range.  The default
	\code{ext=.05} specifies marginal domains of lengths 110 percent
	of their respective ranges.  Prediction outside of the domain
	will result in an error.  Ignored if \code{type="tp"} is
	specified.}
    \item{order}{For thin-plate spline marginals, this option specifies
	the order of the marginal penalties.  Ignored if
	\code{type="cubic"} or \code{type="linear"} are specified.}
}
\details{
    \code{ssanova1} implements an alternative approach to the fitting of
    \code{ssanova} models.  It works in some \eqn{q}-dimensional
    function space determined by a set of "knots" typically through
    random selection; the default dimension (\code{nbasis}) is set to be
    \eqn{q=10n^(2/9)}, adequate for cubic splines.  The algorithms are
    of the order \eqn{O(nq^2)}, scaling much better than the
    \eqn{O(n^3)} of \code{ssanova}; the memory requirements are
    \eqn{O(nq)} versus \eqn{O(n^2)}.

    A simple modification of GCV and Mallows' CL is incorporated in the
    code, to help preventing the occasional severe undersmoothing by
    these methods.  To use the methods unmodified, set \code{alpha=1}.

    To "duplicate" \code{ssanova} fits, use \code{ssanova1} with
    \code{nbasis} set to the sample size and \code{alpha} set to 1;
    numerical discrepancies are to be found, but should be largely
    negligible for practical purposes.  The \code{ssanova1} "duplicates"
    of the \code{ssanova} fits would take much longer to calculate,
    however.

    The model specification via \code{formula} is intuitive.  For
    example, \code{y~x1*x2} yields a model of the form
    \deqn{
	y = c + f_{1}(x1) + f_{2}(x2) + f_{12}(x1,x2) + e
    }
    with the terms denoted by \code{"1"}, \code{"x1"}, \code{"x2"}, and
    \code{"x1:x2"}.  Through the specifications of the side conditions,
    these terms are uniquely defined.  In the current implementation,
    \eqn{f_{1}} and \eqn{f_{12}} integrate to \eqn{0} on the \code{x1}
    domain for cubic spline and linear spline marginals, and add to
    \eqn{0} over the \code{x1} (marginal) sampling points for thin-plate
    spline marginals.

    The penalized least squares problem is equivalent to a certain
    empirical Bayes model or a mixed effect model, and the model terms
    themselves are generally sums of finer terms of two types, the
    unpenalized terms (fixed effects) and the penalized terms (random
    effects).  Attached to every penalized term there is a smoothing
    parameter, and the model complexity is largely determined by the
    number of smoothing parameters.

    The method \code{predict} can be used to evaluate the sum of
    selected or all model terms at arbitrary points within the domain,
    along with standard errors derived from a certain Bayesian
    calculation.  The method \code{summary} has a flag to request
    diagnostics for the practical identifiability and significance of
    the model terms.
}
\note{
    The independent variables appearing in \code{formula} can be
    multivariate themselves.  In particular,
    \code{ssanova(y~x,"tp",order=order)} can be used to fit ordinary
    thin-plate splines in any dimension, of any order permissible, and
    with standard errors available for Bayesian confidence intervals.
    Note that thin-plate splines reduce to polynomial splines in one
    dimension.

    For univariate marginals, the additive models using
    \code{type="cubic"} and \code{type="tp"} yield identical fit through
    different internal makes.  For example,
    \code{ssanova(y~x1+x2,"cubic")} and \code{ssanova(y~x1+x2,"tp")}
    yield the same fit.  The same is not true for models with
    interactions, however.
    
    Mathematically, the domain (through \code{ext} for
    \code{type="cubic"}) or the order (through \code{order} for
    \code{type="tp"}) could be specified individually for each of the
    variables.  Such flexibility is not provided in our implementation,
    however, as it would be more a source for confusion than a practical
    utility.
}
\section{Factors}{
    Factors are accepted as predictors.  When a factor has 3 or more
    levels, all terms involving it are penalized, with the "level means"
    being shrunk towards each other.  The shrinking is done differently
    for nominal and ordinal factors; see \code{\link{mkrk.factor}} for
    details.
}
\value{
    \code{ssanova1} returns a list object of primary class
    \code{"ssanova1"} and secondary class \code{"ssanova"}.

    The method \code{\link{summary}} is used to obtain summaries of the
    fits.  The method \code{\link{predict}} can be used to evaluate the
    fits at arbitrary points, along with the standard errors to be used
    in Bayesian confidence intervals.  The methods
    \code{\link{residuals}} and \code{\link{fitted.values}} extract the
    respective traits from the fits.
}
\seealso{
    \code{\link{ssanova}} and methods \code{\link{predict.ssanova1}},
    \code{\link{summary.ssanova1}}, and \code{\link{fitted.ssanova}}.
}
\author{Chong Gu, \email{chong@stat.purdue.edu}}
\references{
    Kim, Y.-J. and Gu, C. (2002) \emph{Penalized Least Squares
    Regression: Fast Computation via Efficient Approximation}.
    Available at \url{http://stat.purdue.edu/~chong/manu.html}.
  
    Gu, C. (2002), \emph{Smoothing Spline ANOVA Models}.  New York:
    Springer-Verlag.
    
    Wahba, G. (1990), \emph{Spline Models for Observational Data}.
    Philadelphia: SIAM.
}
\examples{
## Fit a cubic spline
x <- runif(100); y <- 5 + 3*sin(2*pi*x) + rnorm(x)
cubic.fit <- ssanova1(y~x)
## Obtain estimates and standard errors on a grid
new <- data.frame(x=seq(min(x),max(x),len=50))
est <- predict(cubic.fit,new,se=TRUE)
## Plot the fit and the Bayesian confidence intervals
plot(x,y,col=1); lines(new$x,est$fit,col=2)
lines(new$x,est$fit+1.96*est$se,col=3)
lines(new$x,est$fit-1.96*est$se,col=3)
## Clean up
\dontrun{rm(x,y,cubic.fit,new,est)
dev.off()}

## Fit a tensor product cubic spline
data(nox)
nox.fit <- ssanova1(log10(nox)~comp*equi,data=nox)
## Fit a spline with cubic and nominal marginals
nox$comp<-as.factor(nox$comp)
nox.fit.n <- ssanova1(log10(nox)~comp*equi,data=nox)
## Fit a spline with cubic and ordinal marginals
nox$comp<-as.ordered(nox$comp)
nox.fit.o <- ssanova1(log10(nox)~comp*equi,data=nox)
## Clean up
\dontrun{rm(nox,nox.fit,nox.fit.n,nox.fit.o)}
}
\keyword{smooth}
\keyword{models}
\keyword{regression}

\eof
\name{ssden}
\alias{ssden}
\title{Estimating Probability Density Using Smoothing Splines}
\description{
    Estimate probability densities using smoothing spline ANOVA models
    with cubic spline, linear spline, or thin-plate spline marginals for
    numerical variables.  The symbolic model specification via
    \code{formula} follows the same rules as in \code{\link{lm}}, but
    with the response missing.
}
\usage{
ssden(formula, type="cubic", data=list(), alpha=1.4, weights=NULL,
      subset, na.action=na.omit, id.basis=NULL, nbasis=NULL, seed=NULL,
      domain=as.list(NULL), quadrature=NULL, ext=.05, order=2,
      prec=1e-7, maxiter=30)
}
\arguments{
    \item{formula}{Symbolic description of the model to be fit.}
    \item{type}{Type of numerical marginals to be used.  Supported are
	\code{type="cubic"} for cubic spline marginals,
	\code{type="linear"} for linear spline marginals, and
	\code{type="tp"} for thin-plate spline marginals.}
    \item{data}{Optional data frame containing the variables in the
        model.}
    \item{alpha}{Parameter defining cross-validation score for smoothing
        parameter selection.}
    \item{weights}{Optional vector of bin-counts for histogram data.}
    \item{subset}{Optional vector specifying a subset of observations
	to be used in the fitting process.}
    \item{na.action}{Function which indicates what should happen when
        the data contain NAs.}
    \item{id.basis}{Index of observations to be used as "knots."}
    \item{nbasis}{Number of "knots" to be used.  Ignored when
        \code{id.basis} is specified.}
    \item{seed}{Seed to be used for the random generation of "knots."
        Ignored when \code{id.basis} is specified.}
    \item{domain}{Data frame specifying marginal support of density.}
    \item{quadrature}{Quadrature for calculating integral.  Mandatory
        for \code{type="tp"}.}
    \item{ext}{For cubic spline and linear spline marginals, this option
	specifies how far to extend the domain beyond the minimum and
	the maximum as a percentage of the range.  The default
	\code{ext=.05} specifies marginal domains of lengths 110 percent
	of their respective ranges.  Evaluation outside of the domain
	will result in an error.  Ignored if \code{type="tp"} or
	\code{domain} are specified.}
    \item{order}{For thin-plate spline marginals, this option specifies
	the order of the marginal penalties.  Ignored if
	\code{type="cubic"} or \code{type="linear"} are specified.}
    \item{prec}{Precision requirement for internal iterations.}
    \item{maxiter}{Maximum number of iterations allowed for
	internal iterations.}
}
\details{
    The model specification via \code{formula} is for the log density.
    For example, \code{~x1*x2} prescribes a model of the form
    \deqn{
	log f(x1,x2) = g_{1}(x1) + g_{2}(x2) + g_{12}(x1,x2) + C
    }
    with the terms denoted by \code{"x1"}, \code{"x2"}, and
    \code{"x1:x2"}; the constant is determined by the fact that a
    density integrates to one.

    The selective term elimination may characterize (conditional)
    independence structures between variables.  For example,
    \code{~x1*x2+x1*x3} yields the conditional independence of x2 and x3
    given x1.  Currently, up to four variables are supported.

    Parallel to those in a \code{\link{ssanova}} object, the model terms
    are sums of unpenalized and penalized terms.  Attached to every
    penalized term there is a smoothing parameter, and the model
    complexity is largely determined by the number of smoothing
    parameters.

    The selection of smoothing parameters is through a cross-validation
    mechanism described in the references, with a parameter
    \code{alpha}; \code{alpha=1} is "unbiased" for the minimization of
    Kullback-Leibler loss but may yield severe undersmoothing, whereas
    larger \code{alpha} yields smoother estimates.

    A subset of the observations are selected as "knots."  Unless
    specified via \code{id.basis} or \code{nbasis}, the subset size is
    determined by \eqn{max(30,10n^(2/9))}, which is appropriate for
    \code{type="cubic"} but not necessarily for \code{type="linear"} or
    \code{type="tp"}.
}
\note{
    For \code{type="cubic"} and \code{type="linear"}, the quadrature
    will be generated if not provided by the user.  The default
    quadrature in 1-D is the 200-point Gauss-Legendre formula on the
    domain.  The default quadratures on 2-D, 3-D, and 4-D cubes are
    selected delayed Smolyak cubatures with 449, 2527, and 13697 points,
    on properly scaled product domains.  See \code{\link{gauss.quad}}
    and \code{\link{smolyak.quad}}.
}
\value{
    \code{ssden} returns a list object of \code{\link{class} "ssden"}.

    \code{\link{dssden}} and \code{\link{cdssden}} can be used to
    evaluate the estimated joint density and conditional density.
    \code{pssden}, \code{qssden}, \code{cpssden}, and \code{cqssden} can
    be used to evaluate (conditional) cdf and quantiles.
}
\seealso{
    \code{\link{dssden}} and \code{\link{cdssden}}.
}
\author{Chong Gu, \email{chong@stat.purdue.edu}}
\references{
    Gu, C. and Wang, J. (2003), Penalized likelihood density
    estimation: Direct cross-validation and scalable approximation.
    \emph{Statistica Sinica}, \bold{13}, 811--826.
  
    Gu, C. (2002), \emph{Smoothing Spline ANOVA Models}.  New York:
    Springer-Verlag.
}
\examples{
## 1-D estimate: Buffalo snowfall
data(buffalo)
buff.fit <- ssden(~buffalo,domain=data.frame(buffalo=c(0,150)))
plot(xx<-seq(0,150,len=101),dssden(buff.fit,xx),type="l")
plot(xx,pssden(buff.fit,xx),type="l")
plot(qq<-seq(0,1,len=51),qssden(buff.fit,qq),type="l")
## Clean up
\dontrun{rm(buffalo,buff.fit,xx,qq)
dev.off()}

## 2-D with triangular domain: AIDS incubation
data(aids)
## rectangular quadrature
quad.pt <- expand.grid(incu=((1:40)-.5)/40*100,infe=((1:40)-.5)/40*100)
quad.pt <- quad.pt[quad.pt$incu<=quad.pt$infe,]
quad.wt <- rep(1,nrow(quad.pt))
quad.wt[quad.pt$incu==quad.pt$infe] <- .5
quad.wt <- quad.wt/sum(quad.wt)*5e3
## additive model (pre-truncation independence)
aids.fit <- ssden(~incu+infe,data=aids,subset=age>=60,
                  domain=data.frame(incu=c(0,100),infe=c(0,100)),
                  quad=list(pt=quad.pt,wt=quad.wt))
## conditional (marginal) density of infe
jk <- cdssden(aids.fit,xx<-seq(0,100,len=51),data.frame(incu=50))
plot(xx,jk$pdf,type="l")
## conditional (marginal) quantiles of infe (TIME-CONSUMING)
\dontrun{
cqssden(aids.fit,c(.05,.25,.5,.75,.95),data.frame(incu=50),jk$int)
}
## Clean up
\dontrun{rm(aids,quad.pt,quad.wt,aids.fit,jk,xx)
dev.off()}
}
\keyword{smooth}
\keyword{models}
\keyword{distribution}

\eof
\name{sshzd}
\alias{sshzd}
\title{Estimating Hazard Function Using Smoothing Splines}
\description{
    Estimate hazard function using smoothing spline ANOVA models
    with cubic spline, linear spline, or thin-plate spline marginals for
    numerical variables.  The symbolic model specification via
    \code{formula} follows the same rules as in \code{\link{lm}}, but
    with the response of a special form.
}
\usage{
sshzd(formula, type="cubic", data=list(), alpha=1.4, weights=NULL,
      subset, na.action=na.omit, id.basis=NULL, nbasis=NULL, seed=NULL,
      ext=.05, order=2, prec=1e-7, maxiter=30)
}
\arguments{
    \item{formula}{Symbolic description of the model to be fit.  Details
        are given below.}
    \item{type}{Type of numerical marginals to be used.  Supported are
	\code{type="cubic"} for cubic spline marginals,
	\code{type="linear"} for linear spline marginals, and
	\code{type="tp"} for thin-plate spline marginals.}
    \item{data}{Optional data frame containing the variables in the
        model.}
    \item{alpha}{Parameter defining cross-validation score for smoothing
        parameter selection.}
    \item{weights}{Optional vector of bin-counts for histogram data.}
    \item{subset}{Optional vector specifying a subset of observations
	to be used in the fitting process.}
    \item{na.action}{Function which indicates what should happen when
        the data contain NAs.}
    \item{id.basis}{Index of observations to be used as "knots."}
    \item{nbasis}{Number of "knots" to be used.  Ignored when
        \code{id.basis} is specified.}
    \item{seed}{Seed to be used for the random generation of "knots."
        Ignored when \code{id.basis} is specified.}
    \item{ext}{For cubic spline and linear spline marginals, this option
	specifies how far to extend the domain beyond the minimum and
	the maximum as a percentage of the range.  The default
	\code{ext=.05} specifies marginal domains of lengths 110 percent
	of their respective ranges.  Evaluation outside of the domain
	will result in an error.  Ignored if \code{type="tp"} or
	\code{domain} are specified.}
    \item{order}{For thin-plate spline marginals, this option specifies
	the order of the marginal penalties.  Ignored if
	\code{type="cubic"} or \code{type="linear"} are specified.}
    \item{prec}{Precision requirement for internal iterations.}
    \item{maxiter}{Maximum number of iterations allowed for
	internal iterations.}
}
\details{
    The model specification via \code{formula} is for the log hazard.
    For example, \code{~x1*x2} prescribes a model of the form
    \deqn{
	log f(x1,x2) = C + g_{1}(x1) + g_{2}(x2) + g_{12}(x1,x2)
    }
    with the terms denoted by \code{"x1"}, \code{"x2"}, and
    \code{"x1:x2"}.

    \code{sshzd} takes standard right-censored lifetime data, with
    possible left-truncation and covariates.  The response in
    \code{formula} must be of the form
    \code{Surv(futime,status,start=0)}, where \code{futime} is the 
    follow-up time, \code{status} is the censoring indicator, and
    \code{start} is the optional left-truncation time.  The function
    \code{Surv} is defined and parsed inside \code{sshzd}, not quite the
    same as the one in the \code{survival} package.

    The main effect of \code{futime} must appear in the model terms.
    The absence of interactions between \code{futime} and covariates
    characterizes proportional hazard models.

    Parallel to those in a \code{\link{ssanova}} object, the model terms
    are sums of unpenalized and penalized terms.  Attached to every
    penalized term there is a smoothing parameter, and the model
    complexity is largely determined by the number of smoothing
    parameters.

    The selection of smoothing parameters is through a cross-validation
    mechanism described in the references, with a parameter
    \code{alpha}; \code{alpha=1} is "unbiased" for the minimization of
    Kullback-Leibler loss but may yield severe undersmoothing, whereas
    larger \code{alpha} yields smoother estimates.

    A subset of the observations are selected as "knots."  Unless
    specified via \code{id.basis} or \code{nbasis}, the subset size is
    determined by \eqn{max(30,10n^(2/9))}, which is appropriate for
    \code{type="cubic"} but not necessarily for \code{type="linear"} or
    \code{type="tp"}.
}
\note{
    Integration on the time axis is done by the 200-point Gauss-Legendre
    formula on [0,T], where T is the largest follow-up time.
}
\value{
    \code{sshzd} returns a list object of \code{\link{class} "sshzd"}.

    \code{\link{hzdrate.sshzd}} can be used to evaluate the estimated
    hazard function.  \code{\link{hzdcurve.sshzd}} can be used to
    evaluate hazard curves with fixed covariates.
    \code{\link{survexp.sshzd}} can be used to calculated estimated
    expected survival.
}
\seealso{
    \code{\link{hzdrate.sshzd}}, \code{\link{hzdcurve.sshzd}}, and
    \code{\link{survexp.sshzd}}.
}
\author{Chong Gu, \email{chong@stat.purdue.edu}}
\references{
    Gu, C. (2002), \emph{Smoothing Spline ANOVA Models}.  New York:
    Springer-Verlag.

    Gu, C. and Wang, J. (2003), Penalized likelihood density
    estimation: Direct cross-validation and scalable approximation.
    \emph{Statistica Sinica}, \bold{13}, 811--826.
}
\examples{
## Model with interaction
data(gastric)
gastric.fit <- sshzd(Surv(futime,status)~futime*trt,data=gastric)
## exp(-Lambda(600)), exp(-(Lambda(1200)-Lambda(600))), and exp(-Lambda(1200))
survexp.sshzd(gastric.fit,c(600,1200,1200),data.frame(trt=as.factor(1)),c(0,600,0))
## Clean up
\dontrun{rm(gastric,gastric.fit)
dev.off()}

## THE FOLLOWING EXAMPLE IS TIME-CONSUMING
## Proportional hazard model
\dontrun{
data(stan)
stan.fit <- sshzd(Surv(futime,status)~futime+age,data=stan)
## Evaluate fitted hazard
hzdrate.sshzd(stan.fit,data.frame(futime=c(10,20),age=c(20,30)))
## Plot lambda(t,age=20)
tt <- seq(0,60,leng=101)
hh <- hzdcurve.sshzd(stan.fit,tt,data.frame(age=20))
plot(tt,hh,type="l")
## Clean up
rm(stan,stan.fit,tt,hh)
dev.off()
}
}
\keyword{smooth}
\keyword{models}
\keyword{survival}

\eof
\name{stan}
\alias{stan}
\title{Stanford Heart Transplant Data}
\description{
    Survival of patients from the Stanford heart transplant program.
}
\usage{data(stan)}
\format{
    A data frame containing 184 observations on the following variables.
    \tabular{ll}{
	\code{time} \tab Follow-up time after transplant, in days.\cr
	\code{status} \tab Censoring status.\cr
	\code{age} \tab Age at transplant.\cr
	\code{futime} \tab Square root of \code{time}.
    }
}
\source{
  Miller, R. G. and Halpern, J. (1982), Regression with censored data.
  \emph{Biometrika}, \bold{69}, 521--531.
}
\keyword{datasets}

\eof
\name{summary.gssanova}
\alias{summary.gssanova}
\title{Assessing Smoothing Spline ANOVA Fits with Non Gaussian Responses}
\description{
    Calculate various summaries of smoothing spline ANOVA fits with non
    Gaussian responses.
}
\usage{
summary.gssanova(object, diagnostics=FALSE, ...)
}
\arguments{
    \item{object}{Object of class \code{"gssanova"}.}
    \item{diagnostics}{Flag indicating if diagnostics are required.}
    \item{...}{Ignored.}
}
\value{
    \code{summary.gssanova} returns a list object of \code{\link{class}}
    \code{"summary.gssanova"} consisting of the following components.
    The entries \code{pi}, \code{kappa}, \code{cosines}, and
    \code{roughness} are only calculated if \code{diagnostics=TRUE}.
    \item{call}{Fitting call.}
    \item{family}{Error distribution.}
    \item{method}{Method for smoothing parameter selection.}
    \item{dispersion}{Assumed or estimated dispersion parameter.}
    \item{iter}{Number of performance-oriented iterations performed.}
    \item{fitted}{Fitted values on the scale of the link.}
    \item{residuals}{Working residuals on the link scale.}
    \item{rss}{Residual sum of squares.}
    \item{dev.resid}{Deviance residuals.}
    \item{deviance}{Deviance of the fit.}
    \item{dev.null}{Deviance of the null model.}
    \item{alpha}{Estimated size for \code{family="nbinomial"} with one
        column responses.  Estimated inverse scale of log life time for
	\code{family="nbinomial"}, \code{"lognorm"}, or
	\code{"loglogis"}.}
    \item{penalty}{Roughness penalty associated with the fit.}
    \item{pi}{"Percentage decomposition" of "explained variance" into
	model terms.}
    \item{kappa}{Concurvity diagnostics for model terms.  Virtually the
	square roots of variance inflation factors of a retrospective
	linear model.}
    \item{cosines}{Cosine diagnostics for practical significance of
	model terms.}
    \item{roughness}{Percentage decomposition of the roughness penalty
      \code{penalty} into model terms.}
}
\details{
    Similar to the iterated weighted least squares fitting of
    \code{\link{glm}}, penalized likelihood regression fit can be calculated
    through iterated penalized weighted least squares.

    The diagnostics are based on the "pseudo" Gaussian response model
    behind the weighted least squares problem at convergence.
}
\author{Chong Gu, \email{chong@stat.purdue.edu}}
\seealso{
    Fitting function \code{\link{gssanova}} and methods
    \code{\link{predict.ssanova}}, \code{\link{fitted.gssanova}}.
}
\keyword{models}
\keyword{regression}
\keyword{smooth}

\eof
\name{summary.gssanova1}
\alias{summary.gssanova1}
\title{Assessing Smoothing Spline ANOVA Fits with Non Gaussian Responses}
\description{
    Calculate various summaries of smoothing spline ANOVA fits with non
    Gaussian responses.
}
\usage{
summary.gssanova1(object, diagnostics=FALSE, ...)
}
\arguments{
    \item{object}{Object of class \code{"gssanova1"}.}
    \item{diagnostics}{Flag indicating if diagnostics are required.}
    \item{...}{Ignored.}
}
\value{
    \code{summary.gssanova1} returns a list object of \code{\link{class}}
    \code{"summary.gssanova1"} consisting of the following components.
    The entries \code{pi}, \code{kappa}, \code{cosines}, and
    \code{roughness} are only calculated if \code{diagnostics=TRUE}.
    \item{call}{Fitting call.}
    \item{family}{Error distribution.}
    \item{alpha}{Parameter used to define cross-validation in model
        fitting.}
    \item{fitted}{Fitted values on the scale of the link.}
    \item{dispersion}{Assumed or estimated dispersion parameter.}
    \item{residuals}{Working residuals on the link scale.}
    \item{rss}{Residual sum of squares.}
    \item{dev.resid}{Deviance residuals.}
    \item{deviance}{Deviance of the fit.}
    \item{dev.null}{Deviance of the null model.}
    \item{penalty}{Roughness penalty associated with the fit.}
    \item{pi}{"Percentage decomposition" of "explained variance" into
	model terms.}
    \item{kappa}{Concurvity diagnostics for model terms.  Virtually the
	square roots of variance inflation factors of a retrospective
	linear model.}
    \item{cosines}{Cosine diagnostics for practical significance of
	model terms.}
    \item{roughness}{Percentage decomposition of the roughness penalty
      \code{penalty} into model terms.}
}
\details{
    Similar to the iterated weighted least squares fitting of
    \code{\link{glm}}, penalized likelihood regression fit can be calculated
    through iterated penalized weighted least squares.

    The diagnostics are based on the "pseudo" Gaussian response model
    behind the weighted least squares problem at convergence.
}
\author{Chong Gu, \email{chong@stat.purdue.edu}}
\seealso{
    Fitting function \code{\link{gssanova1}} and methods
    \code{\link{predict.ssanova}}, \code{\link{fitted.gssanova}}.
}
\keyword{models}
\keyword{regression}
\keyword{smooth}

\eof
\name{summary.ssanova}
\alias{summary.ssanova}
\alias{summary.ssanova1}
\title{Assessing Smoothing Spline ANOVA Fits}
\description{
    Calculate various summaries of smoothing spline ANOVA fits.
}
\usage{
summary.ssanova(object, diagnostics=FALSE, ...)
summary.ssanova1(object, diagnostics=FALSE, ...)
}
\arguments{
    \item{object}{Object of class \code{"ssanova"}.}
    \item{diagnostics}{Flag indicating if diagnostics are required.}
    \item{...}{Ignored.}
}
\value{
    \code{summary.ssanova} returns a list object of \code{\link{class}}
    \code{"summary.ssanova"} consisting of the following components.
    The entries \code{pi}, \code{kappa}, \code{cosines}, and
    \code{roughness} are only calculated if \code{diagnostics=TRUE}; see
    the reference below for details concerning the diagnostics.
    \item{call}{Fitting call.}
    \item{method}{Method for smoothing parameter selection.}
    \item{fitted}{Fitted values.}
    \item{residuals}{Residuals.}
    \item{sigma}{Assumed or estimated error standard deviation.}
    \item{r.squared}{Fraction of "explained variance" by the fitted model.}
    \item{rss}{Residual sum of squares.}
    \item{penalty}{Roughness penalty associated with the fit.}
    \item{pi}{"Percentage decomposition" of "explained variance" into
	model terms.}
    \item{kappa}{Concurvity diagnostics for model terms.  Virtually the
	square roots of variance inflation factors of a retrospective
	linear model.}
    \item{cosines}{Cosine diagnostics for practical significance of
	model terms.}
    \item{roughness}{Percentage decomposition of the roughness penalty
      \code{penalty} into model terms.}
}
\author{Chong Gu, \email{chong@stat.purdue.edu}}
\references{
    Gu, C. (1992), Diagnostics for nonparametric regression models with
    additive terms.  \emph{Journal of the American Statistical
	Association}, \bold{87}, 1051--1058.
}
\seealso{
    Fitting function \code{\link{ssanova}} and methods
    \code{\link{predict.ssanova}}, \code{\link{fitted.ssanova}}.
}
\keyword{models}
\keyword{regression}
\keyword{smooth}

\eof
\name{wesdr}
\alias{wesdr}
\title{Progression of Diabetic Retinopathy}
\description{
    Data derived from the Wisconsin Epidemiological Study of Diabetic
    Retinopathy.
}
\usage{data(wesdr)}
\format{
    A data frame containing 669 observations on the following variables.
    \tabular{ll}{
	\code{dur} \tab Duration of diabetes at baseline, in years.\cr
	\code{gly} \tab Percent of glycosylated hemoglobin at baseline.\cr
	\code{bmi} \tab Body mass index at baseline.\cr
	\code{ret} \tab Binary indicator of retinopathy progression at
	first follow-up.
    }
}
\source{
    Wang, Y. (1997), GRKPACK: Fitting smoothing spline ANOVA models for
    exponential families.  \emph{Communications in Statistics --
    Simulations and Computation}, \bold{26}, 765--782.
}
\references{
    Klein, R., Klein, B. E. K., Moss, S. E., Davis, M. D., and DeMets,
    D. L. (1988), Glycosylated hemoglobin predicts the incidence and
    progression of diabetic retinopathy.  \emph{Journal of the American
    Medical Association}, \bold{260}, 2864--2871.

    Klein, R., Klein, B. E. K., Moss, S. E., Davis, M. D., and DeMets,
    D. L. (1989), The Wisconsin Epidemiologic Study of Diabetic
    Retinopathy. X. Four incidence and progression of diabetic
    retinopathy when age at diagnosis is 30 or more years.
    \emph{Archive Ophthalmology}, \bold{107}, 244--249.

    Wahba, G., Wang, Y., Gu, C., Klein, R., and Klein, B. E. K. (1995),
    Smoothing spline ANOVA for exponential families, with application to
    the Wisconsin Epidemiological Study of Diabetic
    Retinopathy. \emph{The Annals of Statistics}, \bold{23}, 1865--1895.
}
\keyword{datasets}

\eof
